@@ -156,10 +156,10 @@ class CfnNotificationRule(
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
@@ -167,7 +167,23 @@ class CfnNotificationRule(
         :param target_address: ``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                detail_type: builtins.str,
+                event_type_ids: typing.Sequence[builtins.str],
+                name: builtins.str,
+                resource: builtins.str,
+                targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
+                created_by: typing.Optional[builtins.str] = None,
+                event_type_id: typing.Optional[builtins.str] = None,
+                status: typing.Optional[builtins.str] = None,
+                tags: typing.Any = None,
+                target_address: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnNotificationRuleProps(
@@ -192,7 +208,9 @@ class CfnNotificationRule(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -205,17 +223,19 @@ class CfnNotificationRule(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''
@@ -223,12 +243,12 @@ class CfnNotificationRule(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.core.TagManager:
         '''A list of tags to apply to this notification rule.
@@ -239,7 +259,7 @@ class CfnNotificationRule(
         '''
         return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="detailType")
     def detail_type(self) -> builtins.str:
         '''The level of detail to include in the notifications for this resource.
@@ -253,16 +273,18 @@ class CfnNotificationRule(
     @detail_type.setter
     def detail_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "detail_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detailType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventTypeIds")
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -271,11 +293,13 @@ class CfnNotificationRule(
     @event_type_ids.setter
     def event_type_ids(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_ids").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeIds", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''The name for the notification rule.
@@ -289,11 +313,13 @@ class CfnNotificationRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="resource")
     def resource(self) -> builtins.str:
         '''The Amazon Resource Name (ARN) of the resource to associate with the notification rule.
@@ -307,16 +333,18 @@ class CfnNotificationRule(
     @resource.setter
     def resource(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "resource").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="targets")
     def targets(
         self,
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
@@ -328,11 +356,15 @@ class CfnNotificationRule(
         value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "targets").fset)
+            def stub(
+                value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="createdBy")
     def created_by(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
@@ -344,11 +376,13 @@ class CfnNotificationRule(
     @created_by.setter
     def created_by(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "created_by").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventTypeId")
     def event_type_id(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
@@ -360,11 +394,13 @@ class CfnNotificationRule(
     @event_type_id.setter
     def event_type_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="status")
     def status(self) -> typing.Optional[builtins.str]:
         '''The status of the notification rule.
@@ -378,11 +414,13 @@ class CfnNotificationRule(
     @status.setter
     def status(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "status").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="targetAddress")
     def target_address(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
@@ -394,7 +432,9 @@ class CfnNotificationRule(
     @target_address.setter
     def target_address(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "target_address").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetAddress", value)
 
@@ -430,7 +470,13 @@ class CfnNotificationRule(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnNotificationRule.TargetProperty.__init__)
+                def stub(
+                    *,
+                    target_address: builtins.str,
+                    target_type: builtins.str,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
                 check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
             self._values: typing.Dict[str, typing.Any] = {
@@ -507,10 +553,10 @@ class CfnNotificationRuleProps:
         '''Properties for defining a ``CfnNotificationRule``.
 
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
@@ -547,7 +593,21 @@ class CfnNotificationRuleProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRuleProps.__init__)
+            def stub(
+                *,
+                detail_type: builtins.str,
+                event_type_ids: typing.Sequence[builtins.str],
+                name: builtins.str,
+                resource: builtins.str,
+                targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
+                created_by: typing.Optional[builtins.str] = None,
+                event_type_id: typing.Optional[builtins.str] = None,
+                status: typing.Optional[builtins.str] = None,
+                tags: typing.Any = None,
+                target_address: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument event_type_ids", value=event_type_ids, expected_type=type_hints["event_type_ids"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
@@ -592,7 +652,7 @@ class CfnNotificationRuleProps:
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -628,7 +688,7 @@ class CfnNotificationRuleProps:
     def targets(
         self,
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
@@ -711,7 +771,7 @@ class DetailType(enum.Enum):
 class INotificationRule(aws_cdk.core.IResource, typing_extensions.Protocol):
     '''Represents a notification rule.'''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -732,13 +792,13 @@ class INotificationRule(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _INotificationRuleProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''Represents a notification rule.'''
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-codestarnotifications.INotificationRule"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -756,7 +816,9 @@ class _INotificationRuleProxy(
         :return: boolean - return true if it had any effect
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRule.add_target)
+            def stub(target: INotificationRuleTarget) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
@@ -795,7 +857,9 @@ class _INotificationRuleSourceProxy:
         :param scope: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRuleSource.bind_as_notification_rule_source)
+            def stub(scope: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleSourceConfig", jsii.invoke(self, "bindAsNotificationRuleSource", [scope]))
 
@@ -834,7 +898,9 @@ class _INotificationRuleTargetProxy:
         :param scope: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRuleTarget.bind_as_notification_rule_target)
+            def stub(scope: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleTargetConfig", jsii.invoke(self, "bindAsNotificationRuleTarget", [scope]))
 
@@ -850,8 +916,8 @@ class NotificationRule(
 ):
     '''A new notification rule.
 
-    :exampleMetadata: infused
     :resource: AWS::CodeStarNotifications::NotificationRule
+    :exampleMetadata: infused
 
     Example::
 
@@ -903,7 +969,19 @@ class NotificationRule(
         :param notification_rule_name: The name for the notification rule. Notification rule names must be unique in your AWS account. Default: - generated from the ``id``
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                events: typing.Sequence[builtins.str],
+                source: INotificationRuleSource,
+                targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+                detail_type: typing.Optional[DetailType] = None,
+                enabled: typing.Optional[builtins.bool] = None,
+                notification_rule_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = NotificationRuleProps(
@@ -917,7 +995,7 @@ class NotificationRule(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromNotificationRuleArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromNotificationRuleArn")
     @builtins.classmethod
     def from_notification_rule_arn(
         cls,
@@ -932,7 +1010,13 @@ class NotificationRule(
         :param notification_rule_arn: Notification rule ARN (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.from_notification_rule_arn)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                notification_rule_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument notification_rule_arn", value=notification_rule_arn, expected_type=type_hints["notification_rule_arn"])
@@ -945,11 +1029,13 @@ class NotificationRule(
         :param target: The SNS topic or AWS Chatbot Slack target.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.add_target)
+            def stub(target: INotificationRuleTarget) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -997,7 +1083,14 @@ class NotificationRuleOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleOptions.__init__)
+            def stub(
+                *,
+                detail_type: typing.Optional[DetailType] = None,
+                enabled: typing.Optional[builtins.bool] = None,
+                notification_rule_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
@@ -1116,7 +1209,17 @@ class NotificationRuleProps(NotificationRuleOptions):
             rule.add_target(slack)
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleProps.__init__)
+            def stub(
+                *,
+                detail_type: typing.Optional[DetailType] = None,
+                enabled: typing.Optional[builtins.bool] = None,
+                notification_rule_name: typing.Optional[builtins.str] = None,
+                events: typing.Sequence[builtins.str],
+                source: INotificationRuleSource,
+                targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
@@ -1239,7 +1342,9 @@ class NotificationRuleSourceConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleSourceConfig.__init__)
+            def stub(*, source_arn: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument source_arn", value=source_arn, expected_type=type_hints["source_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "source_arn": source_arn,
@@ -1295,7 +1400,13 @@ class NotificationRuleTargetConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleTargetConfig.__init__)
+            def stub(
+                *,
+                target_address: builtins.str,
+                target_type: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
         self._values: typing.Dict[str, typing.Any] = {
